@@ -1,8 +1,8 @@
 """INTEGRATION ENGINE OF RPA FOR PYTHON PACKAGE ~ TEBEL.ORG"""
-# Apache License 2.0, Copyright 2020 Tebel.Automation Private Limited
+# Apache License 2.0, Copyright 2019 Tebel.Automation Private Limited
 # https://github.com/tebelorg/RPA-Python/blob/master/LICENSE.txt
 __author__ = 'Ken Soh <opensource@tebel.org>'
-__version__ = '1.32.0'
+__version__ = '1.33.0'
 
 import subprocess
 import os
@@ -455,7 +455,7 @@ def init(visual_automation = False, chrome_browser = True):
 
     # on Windows, check if there is space in folder path name
     if platform.system() == 'Windows' and ' ' in os.getcwd():
-        print('[RPA][INFO] - to use RPA for Python on Windows, avoid space in folder path name')
+        print('[RPA][INFO] - to use TagUI on Windows, avoid space in folder path name')
         return False
 
     # create entry flow to launch SikuliX accordingly
